SX1261 and sx1262 common library

Dependents:   SX126xDevKit SX1262PingPong SX126X_TXonly SX126X_PingPong_Demo ... more

Fork of SX126xLib by Gregory Cristian

Revision:
2:4ff11ea92fbe
Parent:
1:35d34672a089
Child:
3:7e3595a9ebe0
--- a/sx126x-hal.h	Tue Sep 06 07:04:37 2016 +0000
+++ b/sx126x-hal.h	Fri Sep 23 09:38:34 2016 +0000
@@ -12,50 +12,50 @@
 
 Maintainer: Miguel Luis and Gregory Cristian
 */
-#ifndef __SX1261_HAL_H__
-#define __SX1261_HAL_H__
+#ifndef __SX126x_HAL_H__
+#define __SX126x_HAL_H__
 
 #include "sx126x.h"
 
 /*!
  * \brief The default value of SPI clock
  */
-#define SX1261_SPI_FREQ_DEFAULT                  1000000 // 16000000
+#define SX126x_SPI_FREQ_DEFAULT                  1000000 // 16000000
 
 /*!
  * \brief Actual implementation of a SX1280 radio
  */
-class SX1261Hal : public SX1261
+class SX126xHal : public SX126x
 {
 public:
     /*!
      * \brief Constructor for SX1261Hal with SPI support
      *
      * Represents the physical connectivity with the radio and set callback functions on radio interrupts
      */
-    SX1261Hal( PinName mosi, PinName miso, PinName sclk, PinName nss, PinName busy, PinName dio1, PinName dio2, PinName dio3, PinName rst,
+    SX126xHal( PinName mosi, PinName miso, PinName sclk, PinName nss, PinName busy, PinName dio1, PinName dio2, PinName dio3, PinName rst,
                   void ( *txDone )( ), void ( *rxDone )( ), void ( *rxPblSyncWordHeader )( IrqPblSyncHeaderCode_t val ),
                   void ( *rxTxTimeout )( ),void ( *rxError )( IrqErrorCode_t errorCode ), void ( *rangingDone )( IrqRangingCode_t val ),
                   void ( *cadDone )( bool channelActivityDetected ),
                   void ( *onDioIrq )( ) );
 
     /*!
      * \brief Constructor for SX1261Hal with UART support
      *
      * Represents the physical connectivity with the radio and set callback functions on radio interrupts
      */
-    SX1261Hal( PinName tx, PinName rx, PinName busy, PinName dio1, PinName dio2, PinName dio3, PinName rst,
+    SX126xHal( PinName tx, PinName rx, PinName busy, PinName dio1, PinName dio2, PinName dio3, PinName rst,
                   void ( *txDone )( ), void ( *rxDone )( ), void ( *rxPblSyncWordHeader )( IrqPblSyncHeaderCode_t val ),
                   void ( *rxTxTimeout )( ), void ( *rxError )( IrqErrorCode_t errorCode ), void ( *rangingDone )( IrqRangingCode_t val ),
                   void ( *cadDone )( bool channelActivityDetected ),
                   void ( *onDioIrq )( ) );
 
     /*!
      * \brief Destructor for SX1261Hal with UART support
      *
      * Take care of the correct destruction of the communication objects
      */
-    virtual ~SX1261Hal( )
+    virtual ~SX126xHal( )
     {
         if( this->RadioSpi != 0 )
         {
@@ -201,4 +201,4 @@
     virtual void IoIrqInit( DioIrqHandler irqHandler );
 };
 
-#endif // __SX1261_HAL_H__
+#endif // __SX126x_HAL_H__
@@ -12,50 +12,50 @@
 public:
     /*!
-     * \brief Constructor for SX1261Hal with SPI support
+     * \brief Constructor for SX126xHal with SPI support
      *
      * Represents the physical connectivity with the radio and set callback functions on radio interrupts
@@ -12,50 +12,50 @@
 
     /*!
-     * \brief Constructor for SX1261Hal with UART support
+     * \brief Constructor for SX126xHal with UART support
      *
      * Represents the physical connectivity with the radio and set callback functions on radio interrupts
@@ -12,50 +12,50 @@
 
     /*!
-     * \brief Destructor for SX1261Hal with UART support
+     * \brief Destructor for SX126xHal with UART support
      *
      * Take care of the correct destruction of the communication objects